#!/bin/sh
echo 'name: postgresql-simple
version: 0.4.0.2
id: postgresql-simple-0.4.0.2-22e78caeb54d3dd65485bf306aa8cbaf

license: BSD3
copyright: (c) 2011 MailRank, Inc.
           (c) 2011-2013 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability:
homepage:
package-url:
synopsis: Mid-Level PostgreSQL client library
description: Mid-Level PostgreSQL client library, forked from mysql-simple.
category: Database
author: Bryan O'\''Sullivan, Leon P Smith
pkgpath: databases/hs-postgresql-simple
exposed: True
exposed-modules: Database.PostgreSQL.Simple
                 Database.PostgreSQL.Simple.Arrays
                 Database.PostgreSQL.Simple.BuiltinTypes
                 Database.PostgreSQL.Simple.Copy
                 Database.PostgreSQL.Simple.FromField
                 Database.PostgreSQL.Simple.FromRow
                 Database.PostgreSQL.Simple.LargeObjects
                 Database.PostgreSQL.Simple.HStore
                 Database.PostgreSQL.Simple.HStore.Internal
                 Database.PostgreSQL.Simple.Notification
                 Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.SqlQQ
                 Database.PostgreSQL.Simple.Time
                 Database.PostgreSQL.Simple.Time.Internal
                 Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
                 Database.PostgreSQL.Simple.Transaction
                 Database.PostgreSQL.Simple.TypeInfo
                 Database.PostgreSQL.Simple.TypeInfo.Macro
                 Database.PostgreSQL.Simple.TypeInfo.Static
                 Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Errors
                 Database.PostgreSQL.Simple.Internal
hidden-modules: Database.PostgreSQL.Simple.Compat
                Database.PostgreSQL.Simple.HStore.Implementation
                Database.PostgreSQL.Simple.Time.Implementation
                Database.PostgreSQL.Simple.TypeInfo.Types
trusted: False
import-dirs: /usr/local/lib/ghc/postgresql-simple-0.4.0.2
library-dirs: /usr/local/lib/ghc/postgresql-simple-0.4.0.2
hs-libraries: HSpostgresql-simple-0.4.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: aeson-0.6.2.1-92173c75149e34c3bea9cafc379c1c76
         attoparsec-0.10.4.0-d9fd97cfc1a1748b3cde35adf7fd233b
         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
         blaze-builder-0.3.1.1-71a2ae53eb5daf9e6673db8b47b3b6b5
         blaze-textual-0.2.0.8-213811e05d4d4b83315b938a0f25ef12
         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         postgresql-libpq-0.9.0.1-090b3eef19460778fbfb5ff7cba74ba1
         template-haskell-2.8.0.0-2f3447bb22ecbbb93fd4d823f6841241
         text-0.11.3.1-5af30448b2c3a30eee31b3ea9b549812
         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
         transformers-0.3.0.0-ff2bb6ac67241ebb987351a3db564af0
         uuid-1.3.3-9517522b49b35db9a6181ea36f0396f3
         vector-0.10.0.1-869166d5d49db46ce6c328ea5f8defbf
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-postgresql-simple-0.4.0.2/html/postgresql-simple.haddock
haddock-html: /usr/local/share/doc/hs-postgresql-simple-0.4.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
